package app.views.navigation;

import app.navigation.regular.RegularNavigation;
import app.navigation.regular.RegularNavigationLevel;
import app.navigation.regular.RegularNavigationService;
import app.navigation.regular.components.RegularNavigationHeader;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.router.BeforeEvent;
import com.vaadin.flow.router.HasUrlParameter;
import com.vaadin.flow.router.WildcardParameter;
import org.springframework.beans.factory.annotation.Autowired;

public abstract class NavigationViewBase extends VerticalLayout implements HasUrlParameter<String> {

    protected final RegularNavigation regularNavigation;
    protected final RegularNavigationHeader regularNavigationHeader;

    protected NavigationViewBase(@Autowired RegularNavigationService regularNavigationService,
                                 String route,
                                 RegularNavigationLevel regularNavigationLevel) {
        this.regularNavigation = regularNavigationService.getNewNavigation();
        regularNavigation.setRoute(route);
        regularNavigation.setNavigationLevel(regularNavigationLevel);

        this.regularNavigationHeader = new RegularNavigationHeader(regularNavigation);

        define();
    }

    private void define() {
        add(regularNavigationHeader);
        addClassName("content");
        setAlignItems(FlexComponent.Alignment.CENTER);

        regularNavigation.addRunnableToBeRunAfterSelection(this::configureContent);
    }

    /////////////
    // CONTENT //
    /////////////

    protected abstract void configureContent();

    //////////////
    // OVERRIDE //
    //////////////

    @Override
    public void removeAll() {
        super.removeAll();
        add(regularNavigationHeader);
    }

    @Override
    public void setParameter(BeforeEvent event, @WildcardParameter String param) {
        regularNavigation.setParameter(event, param);
    }
}
